==> qtjambi-websockets-5.15.7-sources.jar: io/qt/websockets/QWebSocketCorsAuthenticator.java <==
package io.qt.websockets;


/**
 * <p>Authenticator object for Cross Origin Requests (CORS)</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html">QWebSocketCorsAuthenticator</a></p>
 */
public class QWebSocketCorsAuthenticator extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#QWebSocketCorsAuthenticator">QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QString)</a></p>
     */
    public QWebSocketCorsAuthenticator(java.lang.String origin){
        super((QPrivateConstructor)null);
        initialize_native(this, origin);
    }
    
    private native static void initialize_native(QWebSocketCorsAuthenticator instance, java.lang.String origin);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#QWebSocketCorsAuthenticator-1">QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QWebSocketCorsAuthenticator)</a></p>
     */
    public QWebSocketCorsAuthenticator(io.qt.websockets.QWebSocketCorsAuthenticator other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebSocketCorsAuthenticator instance, io.qt.websockets.QWebSocketCorsAuthenticator other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#allowed">QWebSocketCorsAuthenticator::allowed()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean allowed(){
        return allowed_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean allowed_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#operator-eq-1">QWebSocketCorsAuthenticator::operator=(QWebSocketCorsAuthenticator)</a></p>
     */
    @io.qt.QtUninvokable
    public final void set(io.qt.websockets.QWebSocketCorsAuthenticator other){
        set_native_cref_QWebSocketCorsAuthenticator(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void set_native_cref_QWebSocketCorsAuthenticator(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#origin">QWebSocketCorsAuthenticator::origin()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#setAllowed">QWebSocketCorsAuthenticator::setAllowed(bool)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setAllowed(boolean allowed){
        setAllowed_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), allowed);
    }
    
    @io.qt.QtUninvokable
    private native void setAllowed_native_bool(long __this__nativeId, boolean allowed);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#swap">QWebSocketCorsAuthenticator::swap(QWebSocketCorsAuthenticator&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void swap(io.qt.websockets.QWebSocketCorsAuthenticator other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QWebSocketCorsAuthenticator(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void swap_native_ref_QWebSocketCorsAuthenticator(long __this__nativeId, long other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebSocketCorsAuthenticator(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QWebSocketCorsAuthenticator clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QWebSocketCorsAuthenticator clone_native(long __this_nativeId);
}

==> qtjambi-websockets-5.15.12-sources.jar: io/qt/websockets/QWebSocketCorsAuthenticator.java <==
package io.qt.websockets;


/**
 * <p>Authenticator object for Cross Origin Requests (CORS)</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html">QWebSocketCorsAuthenticator</a></p>
 */
public class QWebSocketCorsAuthenticator extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#QWebSocketCorsAuthenticator">QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QString)</a></p>
     */
    public QWebSocketCorsAuthenticator(java.lang.String origin){
        super((QPrivateConstructor)null);
        initialize_native(this, origin);
    }
    
    private native static void initialize_native(QWebSocketCorsAuthenticator instance, java.lang.String origin);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#QWebSocketCorsAuthenticator-1">QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QWebSocketCorsAuthenticator)</a></p>
     */
    public QWebSocketCorsAuthenticator(io.qt.websockets.QWebSocketCorsAuthenticator other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebSocketCorsAuthenticator instance, io.qt.websockets.QWebSocketCorsAuthenticator other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#allowed">QWebSocketCorsAuthenticator::allowed()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean allowed(){
        return allowed_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean allowed_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#operator-eq-1">QWebSocketCorsAuthenticator::operator=(QWebSocketCorsAuthenticator)</a></p>
     */
    @io.qt.QtUninvokable
    public final void set(io.qt.websockets.QWebSocketCorsAuthenticator other){
        set_native_cref_QWebSocketCorsAuthenticator(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void set_native_cref_QWebSocketCorsAuthenticator(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#origin">QWebSocketCorsAuthenticator::origin()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#setAllowed">QWebSocketCorsAuthenticator::setAllowed(bool)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setAllowed(boolean allowed){
        setAllowed_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), allowed);
    }
    
    @io.qt.QtUninvokable
    private native void setAllowed_native_bool(long __this__nativeId, boolean allowed);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebsocketcorsauthenticator.html#swap">QWebSocketCorsAuthenticator::swap(QWebSocketCorsAuthenticator&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void swap(io.qt.websockets.QWebSocketCorsAuthenticator other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QWebSocketCorsAuthenticator(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void swap_native_ref_QWebSocketCorsAuthenticator(long __this__nativeId, long other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebSocketCorsAuthenticator(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QWebSocketCorsAuthenticator clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QWebSocketCorsAuthenticator clone_native(long __this_nativeId);
}
